sol.models.club -- Clubs — SoL 4 developers documentation

# `sol.models.club` -- Clubs

class sol.models.club.Club(**kwargs)

  A club, which organizes championships of tourneys.

  associated_players

    Players associated with this club.

  championships

    `Championships` organized by this club.

  classmethod check_insert(session, fields, user_id)

    Check description validity

  check_update(fields)

    Check description validity

  countChampionships()

    Return the number of championships organized by this club.

  countPlayers()

    Return the number of players associated to this club.

  property country

    The name of the club's country.

  couplings

    Kind of pairing method used to build next round, used as default value for the corresponding field when creating a new championship.

  description

    Description of the club.

  email

    Email address of the club.

  emblem

    Logo of the club, used on badges.

    This is just the filename, referencing a picture inside the `sol.emblems_dir` directory.

  federated_players

    Players associated with this federation.

  idclub

    Primary key.

  idowner

    ID of the `user` that is responsible for this record.

  idrating

    Possible `rating` ID, used as default value for the corresponding field when creating a new championship.

  isfederation

    Flag indicating whether the club is also a federation.

  modified

    Last update timestamp.

  nationality

    ISO country code to compute national rankings.

  owner

    The `owner` of this record, admin when `None`.

  prizes

    Kind of prize-giving, used as default value for the corresponding field when creating a new championship.

    This is used to determine which method will be used to assign final prizes. It may be:

    asis

      means that the final prize is the same as the competitor's points;

    fixed

      means the usual way, that is 18 points to the winner, 16 to the second, 14 to the third, 13 to the fourth, …, 1 point to the 16th, 0 points after that;

    fixed40

      similar to fixed, but applied to best fourty scores starting from 1000:

      > 1. 1000

      > 2. 900

      > 3. 800

      > 4. 750

      > 5. 700

      > 6. 650

      > 7. 600

      > 8. 550

      > 9. 500

      > 10. 450

      > 11. 400

      > 12. 375

      > 13. 350

      > 14. 325

      > 15. 300

      > 16. 275

      > 17. 250

      > 18. 225

      > 19. 200

      > 20. 175

      > 21. 150

      > 22. 140

      > 23. 130

      > 24. 120

      > 25. 110

      > 26. 100

      > 27. 90

      > 28. 80

      > 29. 70

      > 30. 60

      > 31. 50

      > 32. 40

      > 33. 35

      > 34. 30

      > 35. 25

      > 36. 20

      > 37. 15

      > 38. 10

      > 39. 5

      > 40. 1

    millesimal

      is the classic method, that distributes a multiple of 1000/num-of-competitors.

  rating

    Default `Ratings` used by this club's championships.

  ratings

    `Ratings` reserved for tourneys organized by this club.

  serialize(serializer)

    Reduce a single club to a simple dictionary.

    Parameters

      serializer -- a `Serializer` instance

    Return type

      dict

    Returns

      a plain dictionary containing a flatified view of this club

  siteurl

    Web site URL.